# coding: utf-8
import json
from typing import Tuple

from ninja.orm.factory import factory
from ninja.orm.fields import get_schema_field
from pydantic import create_model


def create_search_schema(model_name, main_schema, model, fields):
    """Возвращает схему для полей поиска в API."""
    definitions = {}
    for fld in factory._selected_model_fields(model, fields):
        python_type, field_info = get_schema_field(fld, depth=0)
        # Делаем поля поиска необязательными
        field_info.default = None
        definitions[fld.name] = (python_type, field_info)
    SearchModel = create_model(
        model_name,
        **definitions,
        __base__=main_schema,
    )
    return SearchModel


def create_error_response(code: int, exc: Exception) -> Tuple[int, dict]:
    """Формирует ответ при возникновении ошибки обработки запроса."""
    if hasattr(exc, "message_dict"):
        msg = json.dumps(exc.message_dict)
    else:
        msg = json.dumps(str(exc))

    return code, {"message": msg}
